#!/bin/bash

export COMPONENT_HASH=0337a38516fbef155663c4b5fae4a740542d1d28
PKG_VERSION=0.4.15+cdh6.1.1
FULL_VERSION=0.4.15-cdh6.1.1
BASE_VERSION=0.4.15
PKG_RELEASE=875250
CDH_CUSTOMER_PATCH=p0
CDH_PARCEL_CUSTOM_VERSION=0.4.15+cdh6.1.1-875250.xenial
